@@ -1,11 +1,14 @@
-#######################################################################
+########################################################################
 # housekeeping
 ########################################################################
 
-package FindBin::libs   v2.20.2;
-use v5.28;
+package FindBin::libs   v2.12.01;
+
+use v5.14;
+use strict;
 
 use FindBin;
+
 use File::Basename;
 
 use Carp    qw( croak                   );
@@ -18,7 +21,6 @@ qw
     &splitdir
     &catpath
     &catdir
-    &canonpath
 );
 
 BEGIN
@@ -101,6 +103,7 @@ my %found = ();
 
 # saves passing this between import and $handle_args.
 
+my %argz    = ();
 my $verbose = '';
 my $empty   = q{};
 
@@ -116,11 +119,11 @@ my $empty   = q{};
 my $find_libs
 = sub
 {
-    my $argz    = shift;
-    my $base    = basename $argz->{ base };
-    my $subdir  = canonpath $argz->{ subdir } || '';
+    my $base    = basename ( shift || $argz{ base } );
 
-    my $subonly = defined $argz->{ subonly };
+    my $subdir  = $argz{ subdir } || '';
+
+    my $subonly = defined $argz{ subonly };
 
     # for some reason, RH Enterprise V/4 has a 
     # trailing '/'; I havn't seen another copy of 
@@ -134,7 +137,7 @@ my $find_libs
     # after that splitpath can grab the directory 
     # portion for future use.
 
-    my ( $Bin ) = ( $argz->{ Bin } =~ m{^ (.+) }xs );
+    my ( $Bin ) = ( $argz{ Bin } =~ m{^ (.+) }xs );
 
     print STDERR "\nSearching $Bin for '$base'...\n"
     if $verbose;
@@ -187,7 +190,7 @@ my $find_libs
 
                 push @libz, $dir;
 
-                last if $argz->{ scalar };
+                last if $argz{ scalar };
             }
         }
 
@@ -219,7 +222,7 @@ my $handle_args
     # anything after the module are options with arguments
     # assigned via '='.
 
-    my %argz
+    %argz
     = map
     {
         my $use_undef
@@ -322,17 +325,20 @@ my $handle_args
             }
         }
     }
-
-    %argz
 };
 
 sub import
 {
-    # map used here for -T checks. everything from find_libs has
-    # already been through abs_path, not much more to check here.
+    &$handle_args;
 
-    my %argz    = &$handle_args;
-    my @libz    = map { m{ (.+) }xs } $find_libs->( \%argz );
+    my @libz = $find_libs->();
+
+    # HAK ALERT: the regex does nothing for security,
+    # just dodges -T. putting this down here instead
+    # of inside find_libs allows people to use saner
+    # untainting plans via find_libs.
+
+    @libz   = map { m{ (.+) }xs } @libz;
 
     my $caller = caller;
 
@@ -351,7 +357,7 @@ sub import
         # the caller is expecting to exist at runtime -- even
         # if they are empty/undef at the end of it.
 
-        my $ref = qualify_to_ref $argz{ export }, $caller;
+        my $ref     = qualify_to_ref $argz{ export }, $caller;
 
         if( $verbose )
         {
@@ -386,10 +392,10 @@ sub import
         }
     }
 
+    # no 'else', these are not exclusive
+
     if( @libz )
     {
-        # no 'else', these are not exclusive
-
         if( defined $argz{ p5lib } )
         {
             # stuff the lib's found at the front of $ENV{ PERL5LIB }
@@ -406,6 +412,9 @@ sub import
         {
             # this obviously won't work if lib ever depends 
             # on the caller's package.
+            #
+            # it does avoids issues with -T blowing up on the
+            # old eval technique.
 
             require lib;
 
@@ -417,7 +426,9 @@ sub import
 }
 
 # keep require happy
+
 1
+
 __END__
 
 =head1 NAME
@@ -427,6 +438,9 @@ directories based on $FindBin::Bin.
 
 =head1 SYNOPSIS
 
+This version of FindBin::libs is suitable for 
+Perl v5.10+.
+
     # search up $FindBin::Bin looking for ./lib directories
     # and "use lib" them.
 
@@ -919,7 +933,7 @@ may be limited to *NIX or at least less portable.
 
 PERL5LIB can be used to accomplish the same directory
 lookups as FindBin::libs.  The problem is PERL5LIB often
-contains absolute paths and does not automatically change
+contains absolte paths and does not automatically change
 depending on where tests are run. This can leave you 
 modifying a file, changing directory to see if it works
 with some other code and testing an unmodified version of 
@@ -961,7 +975,7 @@ in the executable path (or cwd) and uses that.
 
 The main problem here is that if the anchor ever changes
 (e.g., when moving code between projects or relocating 
-directories) the path often has
+directories now that SVN supports it) the path often has
 to change in multiple files. The regex also may have to
 support multiple platforms, or be broken into more complicated
 File::Spec code that probably looks pretty much like what
@@ -1026,12 +1040,8 @@ directory paths based on $FindBin::Bin.
 
 =item Older code.
 
-There are versions of the code for Perl from releases
-v5.8, 5.14, and 5.28. Makefile.PL will pick the most recent
-version it can based on $^V at Configure time. As of this
-writing Perl is at 5.32, which would pick the 5.28 release. 
-
-The version-specific code is in ./version/<perl-v-string.
+FindBin::libs_5_8.pm is installed if $^V indicates
+that the running perl is prior to v5.10.
 
 =back
 
@@ -1062,12 +1072,12 @@ working version) once the File::Spec is fixed.
 
 =item 
 
-The hack for older versions of perl is 
+The hack for prior-to-5.12 versions of perl is 
 messy, but is the only I've found that works for
 the moment on *NIX, VMS, and MSW. I am not sure
 whether any of these systems are normally configured
 to share perl modules between versions. If the 
-modules are not shared on multiple platforms then
+moduels are not shared on multiple platforms then
 I can make this work by managing the installation
 rather than checking this every time at startup.
 
@@ -1077,7 +1087,9 @@ For the moment, at least, this seems to work.
 
 =head1 SEE ALSO
 
-=over 4
+=head2 Module::FromPerlVer
+
+Explains where the installed version comes from.
 
 =head2 Cwd
 
@@ -1092,11 +1104,11 @@ Steven Lembark, Workhorse Computing <lembark@wrkhors.com>
 
 =head1 COPYRIGHT
 
-Copyright (C) 2003-2020, Steven Lembark, Workhorse Computing.
-This code is released under the same terms as Perl-5.28
+Copyright (C) 2003-2014, Steven Lembark, Workhorse Computing.
+This code is released under the same terms as Perl-5.24
 or any later version of Perl.
 
 =head1 LICENSE
 
-This code is released under the same terms as Perl-5.28
+This code is released under the same terms as Perl-5.24
 or any later version of Perl.
